@@ -1,4 +1,4 @@
-// $Id: callback.cc,v 1.2 2002/02/17 18:53:39 murrayc Exp $
+// $Id: callback.cc,v 1.3 2003/01/28 23:17:29 murrayc Exp $
 
 /* callback.cc
  *
@@ -51,7 +51,7 @@ void CallbackHolder::destroy(void* data)
 void CallbackHolder::call(GConfClient* client, guint i, GConfEntry* pEntry, void* data)
 {
   if(data)
-    ((CallbackHolder*)data)->m_Slot (i, Entry (pEntry));
+    ((CallbackHolder*)data)->m_Slot (i, Entry (pEntry, true));
 }
 
 } /* namespace Conf */
